//
//  YHSearchInfomationVC.swift
//  galaxy
//
//  Created by edy on 2024/4/8.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit

class YHSearchInfomationVC: YHBaseViewController {

    var items:[YHHomeListModel] = []
    
    lazy var viewModel : YHHomePageViewModel = {
        let viewModel = YHHomePageViewModel()
        return viewModel
    }()
    
    lazy var searchBar: YHSearchInfoBar = {
        let bar = YHSearchInfoBar(frame: CGRect(x: 20, y: k_Height_NavigationtBarAndStatuBar+8.0, width: KScreenWidth-40, height: 36.0))
        bar.searchBlock = {
            [weak self] text in
            guard let self = self else { return }
            searchText(self.searchBar.textField.text ?? "")
        }
        bar.textChange = {
            [weak self] text in
            guard let self = self else { return }
            if isEmptyString(text) {
                searchHistoryView.isHidden = false
                items.removeAll()
                self.tableView.reloadData()
            }
        }
        return bar
    }()
    
    lazy var tableView: UITableView = {
        
        let tableView = UITableView(frame:.zero, style:.grouped)

        if #available(iOS 11.0, *) {
            tableView.contentInsetAdjustmentBehavior = .never
        }
        tableView.estimatedSectionHeaderHeight = 0.1
        tableView.estimatedSectionFooterHeight = 20.0
        tableView.showsVerticalScrollIndicator = false
        tableView.separatorStyle = .none
        tableView.delegate = self
        tableView.dataSource = self
        tableView.backgroundColor = .white
        tableView.backgroundView = emptyDataTipsView
        tableView.register(YHSearchInfoCell.self, forCellReuseIdentifier: YHSearchInfoCell.cellReuseIdentifier)
        return tableView
    }()
    
    lazy var searchHistoryView: YHSearchInfoHistoryView = {
        let view = YHSearchInfoHistoryView(frame: CGRect(x: 0, y: searchBar.frame.maxY+8, width: KScreenWidth, height: KScreenHeight-searchBar.frame.maxY-8))
        view.selectBlock = {
            [weak self] text in
            guard let self = self else { return }
            self.searchHistoryView.isHidden = true
            self.searchBar.textField.text = text
            searchText(text)
        }
        return view
    }()
    
    lazy var emptyDataTipsView:UIView = {
        let view = UIView(frame: CGRect(x: 0, y: 0, width: KScreenWidth, height: 124))
        view.isHidden = true
        
        let imgView = UIImageView(image: UIImage(named: "service_center_no_data"))
        imgView.contentMode = .scaleAspectFill
        view.addSubview(imgView)
        
        let label = UILabel()
        label.textColor = UIColor.labelTextColor2
        label.font = UIFont.PFSC_R(ofSize: 14)
        label.textAlignment = .center
        label.text = "无搜索结果".local
        view.addSubview(label)
        
        imgView.snp.makeConstraints { make in
            make.top.equalToSuperview().offset(204)
            make.width.height.equalTo(92)
            make.centerX.equalTo(view)
        }
        
        label.snp.makeConstraints { make in
            make.top.equalTo(imgView.snp.bottom).offset(12)
            make.centerX.equalTo(view)
        }
        return view
    }()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        view.backgroundColor = .white
        view.addSubview(searchBar)
        view.addSubview(tableView)
        view.addSubview(searchHistoryView)
        searchBar.textField.becomeFirstResponder()
        
        searchBar.snp.makeConstraints { make in
            make.left.equalToSuperview().offset(20)
            make.right.equalToSuperview().offset(-20)
            make.top.equalToSuperview().offset(k_Height_NavigationtBarAndStatuBar+8.0)
            make.height.equalTo(36.0)
        }
        
        searchHistoryView.snp.makeConstraints { make in
            make.left.right.equalToSuperview()
            make.top.equalTo(searchBar.snp.bottom).offset(20)
            make.bottom.equalToSuperview()
        }
        
        tableView.snp.makeConstraints { make in
            make.left.right.equalToSuperview()
            make.top.equalTo(searchBar.snp.bottom).offset(8+20)
            make.bottom.equalToSuperview()
        }
    }
    
    func searchText(_ text:String) {
        YHHUD.show(.progress(message: "搜索中..."))
        self.viewModel.searchArticleList(text) {
            [weak self] success, error in
            YHHUD.hide()
            guard let self = self else { return }
            items.removeAll()
            if let arr = self.viewModel.arrHomeNewsData {
                items.append(contentsOf: arr)
            }
            emptyDataTipsView.isHidden = (items.count > 0)
            searchHistoryView.isHidden = true
            self.tableView.reloadData()
        }
    }
}

extension YHSearchInfomationVC: UITableViewDelegate, UITableViewDataSource {
    
    func numberOfSections(in tableView: UITableView) -> Int {
        return items.count
    }

    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return 1
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        
        let cell = tableView.dequeueReusableCell(withIdentifier: YHSearchInfoCell.cellReuseIdentifier, for: indexPath) as! YHSearchInfoCell
        
        if 0 <= indexPath.section && indexPath.section < items.count {
            let item = items[indexPath.section]
            cell.updateModel(item)
        }
        return cell
    }
    
    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        return 70.0
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
       
        if 0 <= indexPath.section && indexPath.section < items.count {
            let model = items[indexPath.section]
            let vc = YHHomeWebViewController()
            vc.url = YHConfigManager.shared.h5Url + "?id=\(model.id)"
            vc.id = model.id
            self.navigationController?.pushViewController(vc)
        }
    }

    private func tableView(_ tableView: UITableView, viewForHeaderInSection section: Int) -> CGFloat {
        return 0.1
    }
    
    private func tableView(_ tableView: UITableView, viewForFooterInSection section: Int) -> CGFloat {
        return 20.0
    }
    
    func tableView(_ tableView: UITableView, viewForFooterInSection section: Int) -> UIView? {
        
        return UIView()
    }
    
    func tableView(_ tableView: UITableView, viewForHeaderInSection section: Int) -> UIView? {
        
        return UIView()
    }
}

